import { TTSProvider } from '../../interfaces';
import { Config } from '../../config/config';
import { OpenAITTSProvider } from './openAITTSProvider';

/**
 * Factory for creating TTS providers
 */
export class TTSProviderFactory {
  static getProvider(config: Config): TTSProvider {
    const providerName = config.ttsProvider;
    const providerConfig = config.ttsProviders[providerName];
    
    if (!providerConfig) {
      throw new Error(`TTS provider "${providerName}" not configured.`);
    }
    
    switch (providerName) {
      case 'openai':
        return new OpenAITTSProvider(providerConfig);
      // Add other providers here
      default:
        throw new Error(`TTS provider "${providerName}" not implemented.`);
    }
  }
}