import fs from 'fs';
import { Config } from '../config/config';

/**
 * Load configuration from a JSON file
 * @param filePath - Path to the configuration file
 * @returns Configuration object
 */
export function loadConfigFromFile(filePath: string): Partial<Config> {
  try {
    const configFile = fs.readFileSync(filePath, 'utf8');
    const config = JSON.parse(configFile);
    console.log(`Loaded configuration from ${filePath}`);
    return config;
  } catch (error) {
    console.error(`Error loading config from ${filePath}:`, error);
    process.exit(1);
  }
}

/**
 * Save configuration to a JSON file
 * @param filePath - Path to save the configuration file
 * @param config - Configuration object to save
 */
export function saveConfigToFile(filePath: string, config: any): void {
  try {
    // Filter out non-configuration properties
    const configToSave = { ...config };
    const keysToExclude = ['_', '$0', 'video_file_path', 'estimate', 'config', 'saveConfig', 'help', 'version', 'h'];
    keysToExclude.forEach(key => delete configToSave[key]);

    fs.writeFileSync(filePath, JSON.stringify(configToSave, null, 2), 'utf8');
    console.log(`Configuration saved to ${filePath}`);
  } catch (error) {
    console.error(`Error saving config to ${filePath}:`, error);
  }
}